Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Option ¶
type Option interface {
// contains filtered or unexported methods
}
Option is the interface for all extraction-related functional options.
func WithLogger ¶
WithLogger provides a zap logger to detail ongoing efforts through the extraction phase.
func WithRegistry ¶
WithRegistry provides an optional registry in which to look for the Busybox image.
Useful for air-gap environments or when working with an OCI cache/proxy.
Click to show internal directories.
Click to hide internal directories.