Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Jaeger ¶
type Jaeger struct {
pulumi.ResourceState
// URL to reach out the Jaeger UI
URL pulumi.StringOutput
PodLabels pulumi.StringMapOutput
// contains filtered or unexported fields
}
func NewJaeger ¶
func NewJaeger( ctx *pulumi.Context, name string, args *JaegerArgs, opts ...pulumi.ResourceOption, ) (*Jaeger, error)
type JaegerArgs ¶
type JaegerArgs struct {
Namespace pulumi.StringInput
Registry pulumi.StringInput
PrometheusURL pulumi.StringInput
// contains filtered or unexported fields
}
type Namespace ¶
type Namespace struct {
pulumi.ResourceState
// Name of the namespace. Is going to be appended a 8-char random string
// for parallel deployments within a single Kubernetes cluster (e.g. CI).
// Pass it to the namespacable resources to deploy them into.
Name pulumi.StringOutput
// Labels of the namespace.
Labels pulumi.StringMapOutput
// contains filtered or unexported fields
}
Namespace is an isolated and secured Kubernetes namespace, with security annotations inherited from Talos practices (i.e. audit/enforce/warn versions to latest, audit/warn to restricted and enforce to baseline).
It is deployed with a basic set of network policies that ensure the network isolation toward adjacent namespaces, and deny all non-explicitly-granted traffic.
func NewNamespace ¶
func NewNamespace( ctx *pulumi.Context, name string, args *NamespaceArgs, opts ...pulumi.ResourceOption, ) (*Namespace, error)
NewNamespace creates a new *Namespace.
type NamespaceArgs ¶
type NamespaceArgs struct {
// Name is an optional value that defines the namespace name.
Name pulumi.StringInput
// AdditionalLabels to pass to the namespace, mostly for filtering purposes.
AdditionalLabels pulumi.StringMapInput
}
type OtelCollector ¶
type OtelCollector struct {
pulumi.ResourceState
Endpoint pulumi.StringOutput
ColdExtractPVCName pulumi.StringPtrOutput
PodLabels pulumi.StringMapOutput
// contains filtered or unexported fields
}
func NewOtelCollector ¶
func NewOtelCollector( ctx *pulumi.Context, name string, args *OtelCollectorArgs, opts ...pulumi.ResourceOption, ) (*OtelCollector, error)
type OtelCollectorArgs ¶
type OtelCollectorArgs struct {
Namespace pulumi.StringInput
Registry pulumi.StringInput
StorageClassName pulumi.StringInput
StorageSize pulumi.StringInput
PVCAccessModes pulumi.StringArrayInput
ColdExtract bool
JaegerURL pulumi.StringInput
PrometheusURL pulumi.StringInput
// contains filtered or unexported fields
}
type Perses ¶ added in v0.2.0
type Perses struct {
pulumi.ResourceState
PodLabels pulumi.StringMapOutput
// contains filtered or unexported fields
}
func NewPerses ¶ added in v0.2.0
func NewPerses(ctx *pulumi.Context, name string, args *PersesArgs, opts ...pulumi.ResourceOption) (*Perses, error)
type PersesArgs ¶ added in v0.2.0
type PersesArgs struct {
Namespace pulumi.StringInput
Registry pulumi.StringInput
// If no Prometheus URL is defined, there will be no data to display,
// hence is required.
PrometheusURL pulumi.StringInput
// contains filtered or unexported fields
}
type Prometheus ¶
type Prometheus struct {
pulumi.ResourceState
URL pulumi.StringOutput
PodLabels pulumi.StringMapOutput
// contains filtered or unexported fields
}
func NewPrometheus ¶
func NewPrometheus( ctx *pulumi.Context, name string, args *PrometheusArgs, opts ...pulumi.ResourceOption, ) (*Prometheus, error)
type PrometheusArgs ¶
type PrometheusArgs struct {
Namespace pulumi.StringInput
Registry pulumi.StringInput
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.